# webcomic-publisher

```
pip install webcomic-publisher
```

```
webcomic_publisher --directory strips/20231209 --output export/20231209
```



- README
- ruff /linting
- faire fonctionner sur JM
- option verbose
